@@ -1,6 +1,10 @@
 from django.core.management.base import BaseCommand
-from .. .models import Invitation
+
+from ...utils import get_invitation_model
+
+Invitation = get_invitation_model()
+
 
 class Command(BaseCommand):
     def handle(self, *args, **options):
-        Invitation.objects.delete_expired_confirmations()
\ No newline at end of file
+        Invitation.objects.delete_expired_confirmations()
