@@ -8,7 +8,6 @@ from .app_settings import app_settings
 
 
 class BaseInvitationManager(models.Manager):
-
     def all_expired(self):
         return self.filter(self.expired_q())
 
@@ -16,8 +15,7 @@ class BaseInvitationManager(models.Manager):
         return self.exclude(self.expired_q())
 
     def expired_q(self):
-        sent_threshold = timezone.now() - timedelta(
-            days=app_settings.INVITATION_EXPIRY)
+        sent_threshold = timezone.now() - timedelta(days=app_settings.INVITATION_EXPIRY)
         q = Q(accepted=True) | Q(sent__lt=sent_threshold)
         return q
 
